Reference guide
***************

.. autosummary::
    :toctree: stubs
    :nosignatures:

    coffea.analysis_objects.JaggedCandidateArray.JaggedCandidateArray
    coffea.analysis_objects.JaggedCandidateArray.JaggedCandidateMethods

.. autosummary::
    :toctree: stubs
    :nosignatures:

    coffea.arrays.Builder.Initialize

.. autosummary::
    :toctree: stubs
    :nosignatures:

    coffea.hist.hist_tools.Hist
    coffea.hist.hist_tools.Bin
    coffea.hist.hist_tools.StringBin
    coffea.hist.hist_tools.Cat
    coffea.hist.hist_tools.Axis
    coffea.hist.hist_tools.DenseAxis
    coffea.hist.hist_tools.SparseAxis
    coffea.hist.export.export1d
    coffea.hist.plot.plot1d
    coffea.hist.plot.plotratio
    coffea.hist.plot.plot2d
    coffea.hist.plot.plotgrid

.. autosummary::
    :toctree: stubs
    :nosignatures:

    coffea.jetmet_tools.FactorizedJetCorrector.FactorizedJetCorrector
    coffea.jetmet_tools.JetResolution.JetResolution
    coffea.jetmet_tools.JetResolutionScaleFactor.JetResolutionScaleFactor
    coffea.jetmet_tools.JetCorrectionUncertainty.JetCorrectionUncertainty
    coffea.jetmet_tools.JetTransformer.JetTransformer

.. autosummary::
    :toctree: stubs
    :nosignatures:

    coffea.lookup_tools.extractor.extractor
    coffea.lookup_tools.extractor.evaluator
    coffea.lookup_tools.dense_lookup.dense_lookup
    coffea.lookup_tools.dense_evaluated_lookup.dense_evaluated_lookup
    coffea.lookup_tools.jme_standard_function.jme_standard_function
    coffea.lookup_tools.jersf_lookup.jersf_lookup
    coffea.lookup_tools.jec_uncertainty_lookup.jec_uncertainty_lookup
    coffea.lookup_tools.root_converters.convert_histo_root_file
    coffea.lookup_tools.csv_converters.convert_btag_csv_file
    coffea.lookup_tools.json_converters.convert_histo_json_file
    coffea.lookup_tools.txt_converters.convert_jec_txt_file
    coffea.lookup_tools.txt_converters.convert_jersf_txt_file
    coffea.lookup_tools.txt_converters.convert_jr_txt_file
    coffea.lookup_tools.txt_converters.convert_junc_txt_file
    coffea.lookup_tools.txt_converters.convert_effective_area_file

.. autosummary::
    :toctree: stubs
    :nosignatures:

    coffea.lumi_tools.__init__.LumiData
    coffea.lumi_tools.__init__.LumiMask
    coffea.lumi_tools.__init__.LumiList

.. autosummary::
    :toctree: stubs
    :nosignatures:

    coffea.processor.processor.ProcessorABC
    coffea.processor.dataframe.LazyDataFrame
    coffea.processor.dataframe.PreloadedDataFrame
    coffea.processor.helpers.Weights
    coffea.processor.helpers.PackedSelection
    coffea.processor.executor.iterative_executor
    coffea.processor.executor.futures_executor
    coffea.processor.executor.run_uproot_job
    coffea.processor.executor.run_parsl_job
    coffea.processor.executor.run_spark_job
    coffea.processor.accumulator.accumulator
    coffea.processor.accumulator.set_accumulator
    coffea.processor.accumulator.dict_accumulator
    coffea.processor.accumulator.defaultdict_accumulator

.. autosummary::
    :toctree: stubs
    :nosignatures:

    coffea.processor.parsl.parsl_executor.ParslExecutor
    coffea.processor.parsl.parsl_executor.parsl_executor

.. autosummary::
    :toctree: stubs
    :nosignatures:

    coffea.processor.spark.spark_executor.SparkExecutor
    coffea.processor.spark.spark_executor.spark_executor


